@@ -312,15 +312,16 @@ class BindingSpec(BaseModel):
         ..., description="Virtual host name with non-ASCII characters escaped as in C."
     )
     routing_key: str = Field("", description="Routing key attached to binding")
-    arguments: Optional[dict] = Field(None, description="Binding arguments")
-    properties_key: str = Field(
-        "",
-        description="Unique identifier composed of the bindings routing key and a hash of its arguments",
+    arguments: Optional[dict] = Field(
+        default_factory=dict, description="Binding arguments"
     )
 
 
 class BindingInfo(BindingSpec):
-    pass
+    properties_key: str = Field(
+        "",
+        description="Unique identifier composed of the bindings routing key and a hash of its arguments",
+    )
 
 
 class ExchangeType(enum.Enum):
@@ -348,7 +349,9 @@ class ExchangeSpec(BaseModel):
         False,
         description="Whether the exchange is internal, i.e. cannot be directly published to by a client.",
     )
-    arguments: Optional[Dict[str, Any]] = Field(None, description="Exchange arguments.")
+    arguments: Optional[Dict[str, Any]] = Field(
+        default_factory=dict, description="Exchange arguments."
+    )
     vhost: str = Field(
         ..., description="Virtual host name with non-ASCII characters escaped as in C."
     )
@@ -431,7 +434,9 @@ class QueueSpec(BaseModel):
         False,
         description="Whether the queue will be deleted automatically when no longer used.",
     )
-    arguments: Optional[Dict[str, Any]] = Field(None, description="Queue arguments.")
+    arguments: Optional[Dict[str, Any]] = Field(
+        default_factory=dict, description="Queue arguments."
+    )
     vhost: str = Field(
         ..., description="Virtual host name with non-ASCII characters escaped as in C."
     )
@@ -602,16 +607,29 @@ def http_api_request(
 
 class RabbitMQAPI:
     def __init__(self, url: str, user: str, password: str):
-        self._auth = (user, password)
         self._url = url
+        self._session = requests.Session()
+        self._session.auth = (user, password)
 
     @classmethod
     def from_zocalo_configuration(cls, zc: zocalo.configuration.Configuration):
-        return cls(
-            url=zc.rabbitmqapi["base_url"],
-            user=zc.rabbitmqapi["username"],
-            password=zc.rabbitmqapi["password"],
-        )
+        instance = None
+        base_url = zc.rabbitmqapi["base_url"]
+        for url in base_url.split(","):
+            instance = cls(
+                url=url,
+                user=zc.rabbitmqapi["username"],
+                password=zc.rabbitmqapi["password"],
+            )
+            try:
+                instance.get("health/checks/alarms")
+                break
+            except requests.ConnectionError as e:
+                logger.warning(f"Could not connect to {url}: {e}")
+                instance = None
+        if not instance:
+            raise RuntimeError(f"Could not connect to RabbitMQ API: {base_url}")
+        return instance
 
     @property
     def health_checks(self) -> Tuple[Dict[str, Any], Dict[str, str]]:
@@ -638,14 +656,22 @@ class RabbitMQAPI:
                 failure[health_check] = response.json()
         return success, failure
 
-    def get(self, endpoint: str, params: Dict[str, Any] = None) -> requests.Response:
-        return requests.get(f"{self._url}/{endpoint}", auth=self._auth, params=params)
+    def get(
+        self, endpoint: str, params: Dict[str, Any] = None, timeout: float | None = None
+    ) -> requests.Response:
+        return self._session.get(
+            f"{self._url}/{endpoint}", params=params, timeout=timeout
+        )
 
     def put(
-        self, endpoint: str, params: Dict[str, Any] = None, json: Dict[str, Any] = None
+        self,
+        endpoint: str,
+        params: Dict[str, Any] = None,
+        json: Dict[str, Any] = None,
+        timeout: float | None = None,
     ) -> requests.Response:
-        return requests.put(
-            f"{self._url}/{endpoint}", auth=self._auth, params=params, json=json
+        return self._session.put(
+            f"{self._url}/{endpoint}", params=params, json=json, timeout=timeout
         )
 
     def post(
@@ -653,14 +679,17 @@ class RabbitMQAPI:
         endpoint: str,
         data: Optional[Dict[str, Any]] = None,
         json: Optional[Dict[str, Any]] = None,
+        timeout: float | None = None,
     ) -> requests.Response:
-        return requests.post(
-            f"{self._url}/{endpoint}", auth=self._auth, data=data, json=json
+        return self._session.post(
+            f"{self._url}/{endpoint}", data=data, json=json, timeout=timeout
         )
 
-    def delete(self, endpoint: str, params: Dict[str, Any] = None) -> requests.Response:
-        return requests.delete(
-            f"{self._url}/{endpoint}", auth=self._auth, params=params
+    def delete(
+        self, endpoint: str, params: Dict[str, Any] = None, timeout: float | None = None
+    ) -> requests.Response:
+        return self._session.delete(
+            f"{self._url}/{endpoint}", params=params, timeout=timeout
         )
 
     def bindings(
@@ -691,13 +720,17 @@ class RabbitMQAPI:
 
     def binding_declare(self, binding: BindingSpec):
         endpoint = f"bindings/{binding.vhost}/e/{binding.source}/{binding.destination_type.value}/{binding.destination}"
-        self.post(
+        resp = self.post(
             endpoint,
             json=binding.dict(
                 exclude_defaults=True,
                 exclude={"vhost", "source", "destination", "destination_type"},
             ),
         )
+        if resp.status_code == 404:
+            logger.error(f"404 not found when declaring {endpoint}")
+        elif resp.status_code == 405:
+            logger.error(f"405 not allowed to declare {endpoint}")
 
     def bindings_delete(
         self,
@@ -777,7 +810,11 @@ class RabbitMQAPI:
 
     def exchange_delete(self, vhost: str, name: str, if_unused: bool = False):
         endpoint = f"exchanges/{vhost}/{name}"
-        self.delete(endpoint, params={"if_unused": if_unused})
+        resp = self.delete(endpoint, params={"if-unused": if_unused})
+        if resp.status_code == 404:
+            logger.error(f"404 not found when deleting {endpoint}")
+        elif resp.status_code == 405:
+            logger.error(f"405 not allowed to delete {endpoint}")
 
     def policies(self, vhost: Optional[str] = None) -> List[PolicySpec]:
         endpoint = "policies"
@@ -829,7 +866,7 @@ class RabbitMQAPI:
         self, vhost: str, name: str, if_unused: bool = False, if_empty: bool = False
     ):
         endpoint = f"queues/{vhost}/{name}"
-        self.delete(endpoint, params={"if_unused": if_unused, "if_empty": if_empty})
+        self.delete(endpoint, params={"if-unused": if_unused, "if-empty": if_empty})
 
     def users(self) -> List[UserSpec]:
         endpoint = "users"
